nltk.parse.nonprojectivedependencyparser module
===============================================

.. automodule:: nltk.parse.nonprojectivedependencyparser
   :members:
   :undoc-members:
   :show-inheritance:
